@@ -3,7 +3,6 @@ import os
 import shutil
 import time
 from typing import List
-
 from .. import configuration
 from ..py_package import PackageStruct, PackageDescription
 from PyInstaller.utils.cliutils.archive_viewer import get_archive, get_data, get_content, get_archive_content
@@ -82,10 +81,9 @@ class CommonDump():
         configuration.progress_session_timeout = session_timeout
         configuration.decompile_file = dict(
             zip(decompile_file, [True for x in decompile_file])) if decompile_file else None
-
         CommonDump.load_plugins(plugin)
-
-        print(f'[*] input:{target_file},to:{output_directory}')
+        os.chdir(os.path.dirname(target_file))
+        print(f'[*] target file input:{target_file}\nto:{output_directory}')
 
         if os.path.exists(output_directory):
             print(f'[+] removing output_directory')
